Learn R Programming

HiCociety (version 0.1.39)

get_all_chr_names: Retrieve chromosome names from .hic file

Description

It retrieves all chromosome names having longer than 2.5Mbp.

Usage

get_all_chr_names(fname)

Value

A character vector containing the names of chromosomes whose genomic lengths exceed 2.5 Mbp.

Arguments

fname

Path to .hic file

Author

Sora Yoon, PhD

Details

To extract all chromosome names from .hic file

Examples

Run this code
myhic=system.file('extdata', 'example.hic', package ='HiCocietyExample')
get_all_chr_names(myhic)

Run the code above in your browser using DataLab