powered by
It retrieves all chromosome names having longer than 2.5Mbp.
get_all_chr_names(fname)
A character vector containing the names of chromosomes whose genomic lengths exceed 2.5 Mbp.
Path to .hic file
Sora Yoon, PhD
To extract all chromosome names from .hic file
myhic=system.file('extdata', 'example.hic', package ='HiCocietyExample') get_all_chr_names(myhic)
Run the code above in your browser using DataLab